#
# spec file for package python-oslo.versionedobjects
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-oslo.versionedobjects
Version:        1.21.0
Release:        3.3
Summary:        Oslo Versioned Objects library
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/o/oslo.versionedobjects/oslo.versionedobjects-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python-iso8601 >= 0.1.11
BuildRequires:  python-jsonschema >= 2.0.0
BuildRequires:  python-oslo.concurrency >= 3.8.0
BuildRequires:  python-oslo.config >= 3.14.0
BuildRequires:  python-oslo.context >= 2.9.0
BuildRequires:  python-oslo.i18n >= 2.1.0
BuildRequires:  python-oslo.log >= 3.11.0
BuildRequires:  python-oslo.messaging >= 5.14.0
BuildRequires:  python-oslo.serialization >= 1.10.0
BuildRequires:  python-oslo.utils >= 3.18.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.8
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-WebOb >= 1.6.0
Requires:       python-iso8601 >= 0.1.11
Requires:       python-jsonschema >= 2.0.0
Requires:       python-netaddr >= 0.7.13
Requires:       python-oslo.concurrency >= 3.8.0
Requires:       python-oslo.config >= 3.14.0
Requires:       python-oslo.context >= 2.9.0
Requires:       python-oslo.i18n >= 2.1.0
Requires:       python-oslo.log >= 3.11.0
Requires:       python-oslo.messaging >= 5.14.0
Requires:       python-oslo.serialization >= 1.10.0
Requires:       python-oslo.utils >= 3.18.0
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
oslo.versionedobjects library deals with DB schema being at different versions
than the code expects, allowing services to be operated safely during upgrades.
It enables DB independent schema by providing an abstraction layer, which
allows us to support SQL and NoSQL Databases. oslo.versionedobjects is also
used in RPC APIs, to ensure upgrades happen without spreading version dependent
code across different services and projects.

%package doc
Summary:        osloversionedobjects library - Documentation
Group:          Documentation/HTML
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 4.7.0
Requires:       %{name} = %{version}

%description doc
This package contains documentation files for %{name}.

%prep
%autosetup -n oslo.versionedobjects-%{version}
%py_req_cleanup

%build
%{py2_build}
%{__python2} setup.py build_sphinx && rm doc/build/html/.buildinfo

%install
%{py2_install}

%check
%{__python2} setup.py testr

%files
%license LICENSE
%doc README.rst ChangeLog
%{python2_sitelib}/*

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.21.0:
  - Fix documentation typo
  - Fix a typo
  - Add Constraints support
  - Fix incorrect timestamp comment
  - Add reno for release notes management
  - Show team and repo badges on README
  - Changed the home-page link
  - Fix recursive deepcopy
  - Replace six.iteritems() with .items()
  - Add ObjectListBase concat methods
  - Fix get_schema() for Enum
  - JSON Schema get_schema implementation for last few fields
  - Refactor get_schema for patterned FieldTypes
  - Updated from global requirements
* Fri Oct 14 2016 tbechtold@suse.com
- Fix Url
* Tue Oct  4 2016 dmueller@suse.com
- * global-requirements.txt sync
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 1.17.0
  * Add get_schema for IPV6Address FieldType class
  * JSON schema get_schema implementation for more complex fields
  * Adds new fields and field types
  * Fix to_json_schema() call
  * Fix remotable object change tracking
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to 1.14.0:
  * Updated from global requirements
  * Add Python 3.5 classifier and venv
* Mon Aug  1 2016 tbechtold@suse.com
- update to 1.13.0:
  * Updated from global requirements
  * Imported Translations from Zanata
  * JSON schema get_schema implementation for common fields
  * JSON schema generation for versioned objects
  * Extend test_hashes to allow extra info gathering
  * Improved error message for Object.coerce
  * Fix ComparableVersionedObject in python 3.4
  * Add objectify decorator for readability
  * Fix a typo in Enum error path
  * Fix issue with coercing valid_values to a tuple
  * Replace safe_utils.getcallargs with inspect.getcallargs
  * Remove direct dependency on babel
  * Introduce fixture to enforce sorted order for object changes
  * Expose object context thru a public property
  * Fix compare_obj() to obey missing/unset fields
  * Add BaseEnumField valid_values introspection
  * Use primitive type name in ValueError for Object field coerce failure
  * Update formatting for example statemachine field
  * Add a pci address  field
  * Remove the executable bit from files
- update _service and switch to upstream spec file
* Mon Apr  4 2016 tbechtold@suse.com
- update to 1.8.0:
  * Updated from global requirements
  * Update .gitreview for stable/mitaka
  [#] Adjust Requires
* Thu Mar  3 2016 tbechtold@suse.com
- update to 1.7.0:
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Deprecate current UUIDField behaviour
  * Make sure functions in child object registries work
  * Fix messages in exceptions raised due to invalid state transitions
  * Update translation setup
  * Updated from global requirements
  * Add ability to pass args/kwargs to obj_class init
  * Updated from global requirements
  * Added a state machine field
  * Use oslo_utils for tupleizing versions
  * Add temporary registry pattern to VersionedObjectRegistry
  * Updated from global requirements
  * Imported Translations from Zanata
  * Updated from global requirements
  * Move compare_obj to the fixture module for external consumption
  * Updated from global requirements
  * Fix MACAddress coerce method to validate string first
  * Updated from global requirements
  * Remove meaningless default value in __get__()
  * Added checking compat using manifest backports
  * Fixed nondeterministicness of extra_data test
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Clean up directory openstack/common
  * Use method is_compatible from olso_utils.versionutils
  * Trival: Remove 'MANIFEST.in'
  * Add a callable to gather extra data for fps
  * Add testing for ObjectVersionChecker fixture
  * Leverage dict comprehension in PEP-0274
  * Use version convert methods from oslo_utils.versionutils
  * Add netaddr-related field types
  * Updated from global requirements
  * Adds new MACAddressField
  * Fix the wrong reference for DeprecationWarning
  * cleanup tox.ini
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Fri Nov 20 2015 bwiedemann@suse.com
- update to 0.13.0:
  * Ensure__repr__ return value is encoded
  * Cleanup docstring for obj_tree_get_versions
  * Add warnings for deprecated IndirectionAPI methods
  * Make tests properly use object_class_action_versions()
  * Make class action calls use version manifest
  * Add SensitiveString field type
  * Fix obj_to_primitive() when used with a manifest
  * Move __contains__ from VersionedObjectDictCompat to VersionedObject
  * Add shields.io version/downloads links/badges into README.rst
  * Change ignore-errors to ignore_errors
  * Added test for DateTimeField in obj_get_change
  * Fix missing value types for log message
* Sat Sep 19 2015 tbechtold@suse.com
- update to 0.10.0:
  * Imported Translations from Zanata
* Tue Sep  1 2015 tbechtold@suse.com
- update to 0.9.0:
  * Updated from global requirements
  * Allow calling obj_to_primitive() with version_manifest
  * Switch back to iso format on the wire
  * Save and re-raise exception
  * Check for obj_relationships in List objects
  * Updated from global requirements
  * Make compat of object lists use manifest function
  * Add tests for subobject backporting by manifest
  * Make ObjectListBase a collections.Sequence
  * Switch from deprecated timeutils.isotime
  * Make direct call to object's obj_from_primitive
  * Add usage information
  * Imported Translations from Transifex
  * Updated from global requirements
  * Add validation on target_version arg when calling obj_to_primitive
* Tue Aug 11 2015 seife+obs@b1-systems.com
- update to 0.7.0:
  0.7.0
  * Fix error handling in the exception module on py3
  * Imported Translations from Transifex
  * Updated from global requirements
  * Add a new DictOfListOfStrings type of field
  0.6.0
  * Fix serializer supported version reporting in object_backport
  * Remove dict assumption from remotable decorator
  * Remove ununsed class in test.py
  * Replace 'hypervisor' with 'provided' version
  * Compound fields now coerce their elements' values
  * Move fixture dependencies to extras
  0.5.2
  * Sort child versions before generating fingerprint
  * Manual update the requirements
  * Remove classifiers not supported
  0.5.0
  * Add oslo.config to requirements
  * Add tox target to find missing requirements
  * fields: allow subclasses in ObjectField/ListOfObjectsField
  * Fix "comparason" typo in doc for ComparableVersionedObject
  * fields: report what the wrong type was when coerce fails
  * Decouple ObjectVersionChecker and VersionedObjectRegistry
  * Updated from global requirements
- update spec file requires from requires.txt
* Fri Jun 12 2015 tbechtold@suse.com
- update to 0.4.0:
  * Remove unnecessary openstack-common.conf
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Mon Jun  8 2015 tbechtold@suse.com
- update to 0.3.0:
  * Imported Translations from Transifex
  * Imported Translations from Transifex
  * Enhance documentation
  * Add delattr support
  * Imported Translations from Transifex
  * Enhance dict compat of VersionedObjectDictCompat
  * Drop outdated notes and docstrings
  * Add field name to error messages in object type checking
  * Adds missing WebOb in requirements.txt
  * Add enum fieldtype field
  * Get the indirection_api from the current VersionedObject class
  * Updated from global requirements
  * Imported Translations from Transifex
- Adjust Requires according to requirements.txt
* Sat May 16 2015 dmueller@suse.com
- update to 0.2.0:
  * Standardize setup.cfg summary for oslo libs
  * Update to the latest version of hacking
  * Copy the default value for field
  * Updated from global requirements
  * New config group for oslo_versionedobjects
* Wed Apr  8 2015 tbechtold@suse.com
- Initial packaging
